@@ -3,9 +3,9 @@
 # Image viewer for terminals that support true colors.
 # Copyright (C) 2014  Egmont Koblinger
 #
-# This program is free software; you can redistribute it and/or modify
+# This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -13,12 +13,28 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License along
-# with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-if [ $# != 1 -o "$1" = "--help" ]; then
-  echo 'Usage: img.sh imagefile' >&2
+sep1=':'
+sep2='::'
+if [ "$1" = "-colon4" -o "$1" = "-official" -o "$1" = "-dejure" ]; then
+  shift
+elif [ "$1" = "-colon3" -o "$1" = "-wrong" ]; then
+  sep2=':'
+  shift
+elif [ "$1" = "-semicolon" -o "$1" = "-common" -o "$1" = "-defacto" ]; then
+  sep1=';'
+  sep2=';'
+  shift
+fi
+
+if [ $# != 1 -o "${1:0:1}" = "-" ]; then
+  echo 'Usage: img.sh [-format] imagefile' >&2
+  echo >&2
+  echo '  -colon4|-official|-dejure:    Official format (default)  \e[38:2::R:G:Bm' >&2
+  echo '  -colon3|-wrong:               Misinterpreted format      \e[38:2:R:G:Bm' >&2
+  echo '  -semicolon|-common|-defacto:  Commonly used format       \e[38;2;R;G;Bm' >&2
   exit 1
 elif [ -z $(type -p convert) ]; then
   echo 'Please install ImageMagick to run this script.' >&2
@@ -34,23 +50,23 @@ declare -a upper lower
 upper=()
 lower=()
 
-convert -thumbnail ${COLUMNS}x "$1" txt:- |
+convert -thumbnail ${COLUMNS}x -define txt:compliance=SVG "$1" txt:- |
 while IFS=',:() ' read col row dummy red green blue rest; do
   if [ "$col" = "#" ]; then
     continue
   fi
 
   if [ $((row%2)) = 0 ]; then
-    upper[$col]="$red;$green;$blue"
+    upper[$col]="$red$sep1$green$sep1$blue"
   else
-    lower[$col]="$red;$green;$blue"
+    lower[$col]="$red$sep1$green$sep1$blue"
   fi
 
   # After reading every second image row, print them out.
   if [ $((row%2)) = 1 -a $col = $((COLUMNS-1)) ]; then
     i=0
     while [ $i -lt $COLUMNS ]; do
-      echo -ne "\\e[38;2;${upper[$i]};48;2;${lower[$i]}m▀"
+      echo -ne "\\e[38${sep1}2${sep2}${upper[$i]};48${sep1}2${sep2}${lower[$i]}m▀"
       i=$((i+1))
     done
     # \e[K is useful when you resize the terminal while this script is still running.
@@ -64,7 +80,7 @@ done
 if [ "${upper[0]}" != "" ]; then
   i=0
   while [ $i -lt $COLUMNS ]; do
-    echo -ne "\\e[38;2;${upper[$i]}m▀"
+    echo -ne "\\e[38${sep1}2${sep2}${upper[$i]}m▀"
     i=$((i+1))
   done
   echo -e "\\e[0m\e[K"
