@@ -361,7 +361,9 @@ FontInfo::create_for_context(vte::glib::RefPtr<PangoContext> context,
 	if (desc)
 		pango_context_set_font_description(context.get(), desc);
 
-	pango_context_set_language(context.get(), language);
+        if (language != nullptr &&
+            language != pango_context_get_language(context.get()))
+                pango_context_set_language(context.get(), language);
 
         /* Make sure our contexts have a font_options set.  We use
           * this invariant in our context hash and equal functions.
@@ -408,19 +410,16 @@ FontInfo*
 FontInfo::create_for_widget(GtkWidget* widget,
                             PangoFontDescription const* desc)
 {
-        auto context = gtk_widget_get_pango_context(widget);
-        auto language = pango_context_get_language(context);
-
 #if VTE_GTK == 3
 	auto screen = gtk_widget_get_screen(widget);
-	return create_for_screen(screen, desc, language);
+	return create_for_screen(screen, desc, nullptr);
 #elif VTE_GTK == 4
         auto display = gtk_widget_get_display(widget);
         auto settings = gtk_settings_get_for_display(display);
         auto fontconfig_timestamp = guint{};
         g_object_get (settings, "gtk-fontconfig-timestamp", &fontconfig_timestamp, nullptr);
-        return create_for_context(vte::glib::make_ref(context),
-                                  desc, language, fontconfig_timestamp);
+        return create_for_context(vte::glib::take_ref(gtk_widget_create_pango_context(widget)),
+                                  desc, nullptr, fontconfig_timestamp);
         // FIXMEgtk4: this uses a per-widget context, while the gtk3 code uses a per-screen
         // one. That means there may be a lot less sharing and a lot more FontInfo's around?
 #endif
